Codebase
========

Notes:

* ArcGIS is not required to use cascade.py - it is a standard Python library.
* All code has been checked using pylint and conforms to the PEP8 Python standards.
* There are unit tests that ensure correct output.

Orderer
-------

.. autoclass:: cascade.orderer.Orderer
   :members:
